@@ -1,6 +1,9 @@
+pub mod ecdh;
 pub mod sign;
 pub mod verify;
 
+pub use ecdh::*;
+
 use wasm_bindgen::prelude::*;
 
 /**
